@@ -32,6 +32,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "diff.h"
 
+#include <QMutex>
+#include <QMutexLocker>
 #include <QProcess>
 #include <QString>
 #include <QMap>
@@ -39,6 +41,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <klocalizedstring.h>
 
+QMutex regExMutex;
+
 // static QString GNUPluralForms(const QString& lang);
 
 using namespace GettextCatalog;
@@ -65,7 +69,10 @@ int GettextStorage::load(QIODevice* device/*, bool readonly*/)
     GettextImportPlugin importer;
     ConversionStatus status = OK;
     int errorLine;
-    status = importer.open(device,this,&errorLine);
+    {
+        QMutexLocker locker(&regExMutex);
+        status = importer.open(device,this,&errorLine);
+    }
 
     //for langs with more than 2 forms
     //we create any form-entries additionally needed
@@ -97,8 +104,9 @@ bool GettextStorage::save(QIODevice* device, bool belongsToProject)
     QString comment=m_header.comment();
     QString catalogProjectId;//=m_url.fileName();
     //catalogProjectId=catalogProjectId.left(catalogProjectId.lastIndexOf('.'));
-    updateHeader(header,
-                 comment,
+    {
+        QMutexLocker locker(&regExMutex);
+        updateHeader(header, comment,
                  m_targetLangCode,
                  m_numberOfPluralForms,
                  catalogProjectId,
@@ -106,6 +114,7 @@ bool GettextStorage::save(QIODevice* device, bool belongsToProject)
                  belongsToProject,
                  /*forSaving*/true,
                  m_codec);
+    }
     m_header.setMsgstr(header);
     m_header.setComment(comment);
 
@@ -283,7 +292,7 @@ QVector<Note> GettextStorage::notes(const DocPosition& docPosition, const QRegEx
         if (s.size()>=preLen)
         {
             content+=s.midRef(preLen);
-            content+='\n';
+            content+=QLatin1Char('\n');
         }
     }
 
@@ -318,7 +327,10 @@ QStringList GettextStorage::sourceFiles(const DocPosition& pos) const
     static const QRegExp i18n_file_re(QStringLiteral("^#. i18n: file: "));
     foreach(const QString &uiLine, commentLines.filter(i18n_file_re))
     {
-        result+=uiLine.mid(15).split(' ');
+        foreach(const QStringRef &fileRef, uiLine.midRef(15).split(' '))
+        {
+            result << fileRef.toString();
+        }
     }
 
     bool hasUi=!result.isEmpty();
@@ -326,8 +338,10 @@ QStringList GettextStorage::sourceFiles(const DocPosition& pos) const
     foreach(const QString &cppLine, commentLines.filter(cpp_re))
     {
         if (hasUi && cppLine.startsWith(QLatin1String("#: rc.cpp"))) continue;
-        QStringList cppFiles=cppLine.mid(3).split(' ');
-        result+=cppFiles;
+        foreach(const QStringRef &fileRef, cppLine.midRef(3).split(' '))
+        {
+            result << fileRef.toString();
+        }
     }
     return result;
 }
