@@ -1,9 +1,9 @@
 /* ****************************************************************************
-  This file is part of KAider
+  This file is part of Lokalize
   This file is based on the one from KBabel
 
   Copyright (C) 2002-2003 by Stanislav Visnovsky <visnovsky@kde.org>
-		2007	  by Nick Shaforostoff <shafff@ukr.net>
+                2007-2014 by Nick Shaforostoff <shafff@ukr.net>
 
 
   This program is free software; you can redistribute it and/or modify
@@ -40,16 +40,17 @@
 
 #include <QStringList>
 #include <QLinkedList>
+#include <QDebug>
 
-#include <kdebug.h>
 #include <kmessagebox.h>
-//#include <kservicetypetrader.h>
 
 namespace GettextCatalog 
 {
 
 CatalogImportPlugin::CatalogImportPlugin()
     : _maxLineLength(0)
+    , _trailingNewLines(0)
+    , _errorLine(0)
     , d(new CatalogImportPluginPrivate)
 {
 }
@@ -64,9 +65,9 @@ void CatalogImportPlugin::appendCatalogItem( const CatalogItem& item, const bool
     if (item.msgid().isEmpty())
         return;
     if( obsolete )
-	d->_obsoleteEntries.append(item);
+        d->_obsoleteEntries.append(item);
     else
-	d->_entries.append(item);
+        d->_entries.append(item);
 }
 
 void CatalogImportPlugin::setCatalogExtraData( const QStringList& data )
