@@ -1,5 +1,5 @@
 /*
-Copyright 2008-2012 Nick Shaforostoff <shaforostoff@kde.ru>
+Copyright 2008-2014 Nick Shaforostoff <shaforostoff@kde.ru>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -25,6 +25,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "version.h"
 #include "prefs_lokalize.h"
 
+#include <QDebug>
 #include <QProcess>
 #include <QString>
 #include <QMap>
@@ -32,24 +33,26 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QTime>
 #include <QPair>
 #include <QList>
-
-
-#include <kdebug.h>
-#include <kglobal.h>
-#include <klocale.h>
-#include <kdatetime.h>
 #include <QXmlSimpleReader>
 
-static const char* const noyes[]={"no","yes"};
+#include <klocalizedstring.h>
 
-static const QString names[]={"source" ,"translation","oldsource" ,"translatorcomment","comment" ,"name" ,"numerus"};
-enum TagNames                {SourceTag,TargetTag    ,OldSourceTag,NoteTag            ,DevNoteTag,NameTag,PluralTag};
+#ifdef Q_OS_WIN
+#define U QLatin1String
+#else
+#define U QStringLiteral
+#endif
 
-static const QString attrnames[]={"location"  ,"type"  ,"obsolete"};
-enum AttrNames                   {LocationAttr,TypeAttr,ObsoleteAttr};
+//static const char* const noyes[]={"no","yes"};
 
-static const QString attrvalues[]={"obsolete"};
-enum AttValues                    {ObsoleteVal};
+static const QString names[]={U("source"),U("translation"),U("oldsource"),U("translatorcomment"),U("comment"),U("name"),U("numerus")};
+enum TagNames                {SourceTag  ,TargetTag       ,OldSourceTag  ,NoteTag               ,DevNoteTag  ,NameTag  ,PluralTag};
+
+static const QString attrnames[]={U("location"),U("type"),U("obsolete")};
+enum AttrNames                   {LocationAttr ,TypeAttr ,ObsoleteAttr};
+
+static const QString attrvalues[]={U("obsolete"),U("vanished")};
+enum AttValues                    {ObsoleteVal  ,VanishedVal};
 
 TsStorage::TsStorage()
  : CatalogStorage()
@@ -73,8 +76,8 @@ int TsStorage::load(QIODevice* device)
 
 
     QXmlSimpleReader reader;
-    reader.setFeature("http://qtsoftware.com/xml/features/report-whitespace-only-CharData",true);
-    reader.setFeature("http://xml.org/sax/features/namespaces",false);
+    reader.setFeature(QStringLiteral("http://qt-project.org/xml/features/report-whitespace-only-CharData"),true);
+    reader.setFeature(QStringLiteral("http://xml.org/sax/features/namespaces"),false);
     QXmlInputSource source(device);
 
     QString errorMsg;
@@ -83,29 +86,29 @@ int TsStorage::load(QIODevice* device)
 
     if (!success)
     {
-        kWarning()<<errorMsg;
+        qWarning()<<"parse error"<<errorMsg<<errorLine;
         return errorLine+1;
     }
 
 
-    QDomElement file=m_doc.elementsByTagName("TS").at(0).toElement();
-    m_sourceLangCode=file.attribute("sourcelanguage");
-    m_targetLangCode=file.attribute("language");
+    QDomElement file=m_doc.elementsByTagName(QStringLiteral("TS")).at(0).toElement();
+    m_sourceLangCode=file.attribute(QStringLiteral("sourcelanguage"));
+    m_targetLangCode=file.attribute(QStringLiteral("language"));
     m_numberOfPluralForms=numberOfPluralFormsForLangCode(m_targetLangCode);
 
     //Create entry mapping.
     //Along the way: for langs with more than 2 forms
     //we create any form-entries additionally needed
 
-    entries=m_doc.elementsByTagName("message");
-    int size=entries.size();
+    entries=m_doc.elementsByTagName(QStringLiteral("message"));
 
-    kWarning()<<chrono.elapsed();
+    qWarning()<<chrono.elapsed()<<"secs, "<<entries.size()<<"entries";
     return 0;
 }
 
 bool TsStorage::save(QIODevice* device, bool belongsToProject)
 {
+    Q_UNUSED(belongsToProject)
     QTextStream stream(device);
     m_doc.save(stream,4);
     return true;
@@ -127,7 +130,7 @@ int TsStorage::size() const
 /**
  * helper structure used during XLIFF XML walk-through
  */
-struct ContentEditingData
+struct TsContentEditingData
 {
     enum ActionType{Get,DeleteText,InsertText,CheckLength};
 
@@ -137,21 +140,21 @@ struct ContentEditingData
     ActionType actionType;
 
     ///Get
-    ContentEditingData(ActionType type=Get)
+    TsContentEditingData(ActionType type=Get)
     : pos(-1)
     , lengthOfStringToRemove(-1)
     , actionType(type)
     {}
 
     ///DeleteText
-    ContentEditingData(int p, int l)
+    TsContentEditingData(int p, int l)
     : pos(p)
     , lengthOfStringToRemove(l)
     , actionType(DeleteText)
     {}
 
     ///InsertText
-    ContentEditingData(int p,const QString& s)
+    TsContentEditingData(int p,const QString& s)
     : stringToInsert(s)
     , pos(p)
     , lengthOfStringToRemove(-1)
@@ -159,27 +162,27 @@ struct ContentEditingData
     {}
 };
 
-static QString doContent(QDomElement elem, int startingPos, ContentEditingData* data);
+static QString doContent(QDomElement elem, int startingPos, TsContentEditingData* data);
 
 /**
- * walks through XLIFF XML and performs actions depending on ContentEditingData:
+ * walks through XLIFF XML and performs actions depending on TsContentEditingData:
  * - reads content
  * - deletes content, or
  * - inserts content
  */
-static QString content(QDomElement elem, ContentEditingData* data=0)
+static QString content(QDomElement elem, TsContentEditingData* data=0)
 {
     return doContent(elem, 0, data);
 }
 
-static QString doContent(QDomElement elem, int startingPos, ContentEditingData* data)
+static QString doContent(QDomElement elem, int startingPos, TsContentEditingData* data)
 {
     //actually startingPos is current pos
 
     QString result;
 
     if (elem.isNull()
-        || (!result.isEmpty() && ContentEditingData::CheckLength))
+        || (!result.isEmpty() && data && data->actionType==TsContentEditingData::CheckLength))
         return QString();
 
     bool seenCharacterDataAfterElement=false;
@@ -201,7 +204,7 @@ static QString doContent(QDomElement elem, int startingPos, ContentEditingData*
                 int localStartPos=data->pos-startingPos;
 
                 //BEGIN DELETE TEXT
-                if (data->actionType==ContentEditingData::DeleteText) //(data->lengthOfStringToRemove!=-1)
+                if (data->actionType==TsContentEditingData::DeleteText) //(data->lengthOfStringToRemove!=-1)
                 {
                     if (localStartPos+data->lengthOfStringToRemove>cData.size())
                     {
@@ -218,23 +221,23 @@ static QString doContent(QDomElement elem, int startingPos, ContentEditingData*
                     {
                         //qWarning()<<"simple delete"<<localStartPos<<data->lengthOfStringToRemove;
                         c.deleteData(localStartPos,data->lengthOfStringToRemove);
-                        data->actionType=ContentEditingData::CheckLength;
+                        data->actionType=TsContentEditingData::CheckLength;
                         return QString('a');//so it exits 100%
                     }
                 }
                 //END DELETE TEXT
                 //INSERT
-                else if (data->actionType==ContentEditingData::InsertText)
+                else if (data->actionType==TsContentEditingData::InsertText)
                 {
                     c.insertData(localStartPos,data->stringToInsert);
-                    data->actionType=ContentEditingData::CheckLength;
+                    data->actionType=TsContentEditingData::CheckLength;
                     return QString('a');//so it exits 100%
                 }
                 cData=c.data();
             }
             //else
             //    if (data&&data->pos!=-1/*&& n.nextSibling().isNull()*/)
-            //        kWarning()<<"arg!"<<startingPos<<"data->pos"<<data->pos;
+            //        qWarning()<<"arg!"<<startingPos<<"data->pos"<<data->pos;
 
             result += cData;
             startingPos+=cData.size();
@@ -257,7 +260,7 @@ static QString doContent(QDomElement elem, int startingPos, ContentEditingData*
 CatalogString TsStorage::catalogString(QDomElement contentElement) const
 {
     CatalogString catalogString;
-    ContentEditingData data(ContentEditingData::Get);
+    TsContentEditingData data(TsContentEditingData::Get);
     catalogString.string=content(contentElement, &data);
     return catalogString;
 }
@@ -288,13 +291,13 @@ QString TsStorage::target(const DocPosition& pos) const
 
 void TsStorage::targetDelete(const DocPosition& pos, int count)
 {
-    ContentEditingData data(pos.offset,count);
+    TsContentEditingData data(pos.offset,count);
     content(targetForPos(pos),&data);
 }
 
 void TsStorage::targetInsert(const DocPosition& pos, const QString& arg)
 {
-    kWarning()<<pos.entry<<arg;
+    qWarning()<<pos.entry<<arg;
     QDomElement targetEl=targetForPos(pos);
     //BEGIN add <*target>
     if (targetEl.isNull())
@@ -312,7 +315,7 @@ void TsStorage::targetInsert(const DocPosition& pos, const QString& arg)
     //END add <*target>
     if (arg.isEmpty()) return; //means we were called just to add <taget> tag
 
-    ContentEditingData data(pos.offset,arg);
+    TsContentEditingData data(pos.offset,arg);
     content(targetEl,&data);
 }
 
@@ -343,8 +346,8 @@ QStringList TsStorage::sourceFiles(const DocPosition& pos) const
     QDomElement elem = unitForPos(pos.entry).firstChildElement(attrnames[LocationAttr]);
     while (!elem.isNull())
     {
-        QString sourcefile=elem.attribute("filename");
-        QString linenumber=elem.attribute("line");
+        QString sourcefile=elem.attribute(QStringLiteral("filename"));
+        QString linenumber=elem.attribute(QStringLiteral("line"));
         if (!( sourcefile.isEmpty()&&linenumber.isEmpty() ))
             result.append(sourcefile+':'+linenumber);
 
@@ -389,7 +392,7 @@ QVector<Note> TsStorage::developerNotes(const DocPosition& pos) const
 
 Note TsStorage::setNote(DocPosition pos, const Note& note)
 {
-    //kWarning()<<int(pos.form)<<note.content;
+    //qWarning()<<int(pos.form)<<note.content;
     QDomElement unit=unitForPos(pos.entry);
     QDomElement elem;
     Note oldNote;
@@ -402,7 +405,7 @@ Note TsStorage::setNote(DocPosition pos, const Note& note)
     else
     {
         QDomNodeList list=unit.elementsByTagName(names[NoteTag]);
-        if (pos.form==-1) pos.form=list.size()-1;
+        //if (pos.form==-1) pos.form=list.size()-1;
         if (pos.form<list.size())
         {
             elem = unit.elementsByTagName(names[NoteTag]).at(pos.form).toElement();
@@ -414,13 +417,13 @@ Note TsStorage::setNote(DocPosition pos, const Note& note)
 
     if (!elem.text().isEmpty())
     {
-        ContentEditingData data(0,elem.text().size());
+        TsContentEditingData data(0,elem.text().size());
         content(elem,&data);
     }
 
     if (!note.content.isEmpty())
     {
-        ContentEditingData data(0,note.content);
+        TsContentEditingData data(0,note.content);
         content(elem,&data);
     }
     else
@@ -478,34 +481,38 @@ void TsStorage::setApproved(const DocPosition& pos, bool approved)
     if (approved)
         target.removeAttribute(attrnames[TypeAttr]);
     else
-        target.setAttribute(attrnames[TypeAttr],"unfinished");
+        target.setAttribute(attrnames[TypeAttr],QStringLiteral("unfinished"));
 }
 
 bool TsStorage::isApproved(const DocPosition& pos) const
 {
     QDomElement target=unitForPos(pos.entry).firstChildElement(names[TargetTag]);
-    return !target.hasAttribute(attrnames[TypeAttr]);
+    return !target.hasAttribute(attrnames[TypeAttr]) || target.attribute(attrnames[TypeAttr])==attrvalues[VanishedVal];
 }
 
 bool TsStorage::isObsolete(int entry) const
 {
     QDomElement target=unitForPos(entry).firstChildElement(names[TargetTag]);
-    return target.attribute(attrnames[TypeAttr])==attrvalues[ObsoleteVal];
+    QString v=target.attribute(attrnames[TypeAttr]);
+    return v==attrvalues[ObsoleteVal] || v==attrvalues[VanishedVal];
 }
 
 bool TsStorage::isEmpty(const DocPosition& pos) const
 {
-    ContentEditingData data(ContentEditingData::CheckLength);
+    TsContentEditingData data(TsContentEditingData::CheckLength);
     return content(targetForPos(pos),&data).isEmpty();
 }
 
 bool TsStorage::isEquivTrans(const DocPosition& pos) const
 {
+    Q_UNUSED(pos)
     return true;//targetForPos(pos.entry).attribute("equiv-trans")!="no";
 }
 
 void TsStorage::setEquivTrans(const DocPosition& pos, bool equivTrans)
 {
+    Q_UNUSED(pos)
+    Q_UNUSED(equivTrans)
     //targetForPos(pos.entry).setAttribute("equiv-trans",noyes[equivTrans]);
 }
 
@@ -523,9 +530,9 @@ QDomElement TsStorage::targetForPos(DocPosition pos) const
     
     if (pos.form==-1) pos.form=0;
     
-    QDomNodeList forms=translation.elementsByTagName("numerusform");
+    QDomNodeList forms=translation.elementsByTagName(QStringLiteral("numerusform"));
     while (pos.form>=forms.size())
-        translation.appendChild( unit.ownerDocument().createElement("numerusform") );
+        translation.appendChild( unit.ownerDocument().createElement(QStringLiteral("numerusform")) );
     return forms.at(pos.form).toElement();
 }
 
@@ -534,6 +541,19 @@ QDomElement TsStorage::sourceForPos(int pos) const
     return unitForPos(pos).firstChildElement(names[SourceTag]);
 }
 
+void TsStorage::setTargetLangCode(const QString& langCode)
+{
+    m_targetLangCode=langCode;
+
+    QDomElement file=m_doc.elementsByTagName(QStringLiteral("TS")).at(0).toElement();
+    if (m_targetLangCode!=file.attribute(QStringLiteral("language")).replace('-', '_'))
+    {
+        QString l=langCode;
+        file.setAttribute(QStringLiteral("language"), l.replace('_', '-'));
+    }
+}
+
+
 //END STORAGE TRANSLATION
 
 
