@@ -25,12 +25,11 @@
 #include "catalogmodel.h"
 #include "catalog.h"
 #include "project.h"
+#include "prefs.h"
+#include "headerviewmenu.h"
 
-#include <klocale.h>
-#include <kdebug.h>
-#include <klineedit.h>
-#include <KConfigGroup>
-
+#include <QLineEdit>
+#include <QDebug>
 #include <QTime>
 #include <QTreeView>
 #include <QHeaderView>
@@ -40,12 +39,15 @@
 #include <QAction>
 #include <QMenu>
 #include <QShortcut>
-
 #include <QMdiSubWindow>
 #include <QMdiArea>
-
 #include <QKeyEvent>
 
+#include <klocalizedstring.h>
+#ifndef NOKDE
+#include <kconfiggroup.h>
+#endif
+
 class CatalogTreeView: public QTreeView
 {
     public:
@@ -69,11 +71,11 @@ class CatalogTreeView: public QTreeView
 CatalogView::CatalogView(QWidget* parent, Catalog* catalog)
     : QDockWidget ( i18nc("@title:window aka Message Tree","Translation Units"), parent)
     , m_browser(new CatalogTreeView(this))
-    , m_lineEdit(new KLineEdit(this))
+    , m_lineEdit(new QLineEdit(this))
     , m_model(new CatalogTreeModel(this,catalog))
     , m_proxyModel(new CatalogTreeFilterModel(this))
 {
-    setObjectName("catalogTreeView");
+    setObjectName(QStringLiteral("catalogTreeView"));
 
     QWidget* w=new QWidget(this);
     QVBoxLayout* layout=new QVBoxLayout(w);
@@ -83,8 +85,8 @@ CatalogView::CatalogView(QWidget* parent, Catalog* catalog)
     l->setSpacing(0);
     layout->addLayout(l);
 
-    m_lineEdit->setClearButtonShown(true);
-    m_lineEdit->setClickMessage(i18n("Quick search..."));
+    m_lineEdit->setClearButtonEnabled(true);
+    m_lineEdit->setPlaceholderText(i18n("Quick search..."));
     m_lineEdit->setToolTip(i18nc("@info:tooltip","Activated by Ctrl+L.")+" "+i18nc("@info:tooltip","Accepts regular expressions"));
     connect (m_lineEdit,SIGNAL(textChanged(QString)),this,SLOT(setFilterRegExp()),Qt::QueuedConnection);
     // QShortcut* ctrlEsc=new QShortcut(QKeySequence(Qt::META+Qt::Key_Escape),this,SLOT(reset()),0,Qt::WidgetWithChildrenShortcut);
@@ -117,6 +119,12 @@ CatalogView::CatalogView(QWidget* parent, Catalog* catalog)
     m_browser->setAllColumnsShowFocus(true);
     m_browser->setAlternatingRowColors(true);
     m_browser->viewport()->setBackgroundRole(QPalette::Background);
+#ifdef Q_OS_DARWIN
+    QPalette p;
+    p.setColor(QPalette::AlternateBase, p.color(QPalette::Background).darker(110));
+    p.setColor(QPalette::Highlight, p.color(QPalette::Background).darker(150));
+    m_browser->setPalette(p);
+#endif
 
     m_proxyModel->setSourceModel(m_model);
     m_browser->setModel(m_proxyModel);
@@ -127,17 +135,13 @@ CatalogView::CatalogView(QWidget* parent, Catalog* catalog)
     m_browser->setUniformRowHeights(true);
     m_browser->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);
 
-
-    KConfig config;
-    KConfigGroup cg(&config,"MainWindow");
-    m_browser->header()->restoreState(QByteArray::fromBase64( cg.readEntry("TreeHeaderState", QByteArray()) ));
+    new HeaderViewMenuHandler(m_browser->header());
+    m_browser->header()->restoreState(readUiState("CatalogTreeViewState"));
 }
 
 CatalogView::~CatalogView()
 {
-    KConfig config;
-    KConfigGroup cg(&config,"MainWindow");
-    cg.writeEntry("TreeHeaderState",m_browser->header()->saveState().toBase64());
+    writeUiState("CatalogTreeViewState", m_browser->header()->saveState());
 }
 
 void CatalogView::setFocus()
@@ -201,7 +205,9 @@ void CatalogView::fillFilterOptionsMenu()
                                  I18N_NOOP("Unchanged since file open"),
                                  I18N_NOOP("Same in sync file"),
                                  I18N_NOOP("Different in sync file"),
-                                 I18N_NOOP("Not in sync file")
+                                 I18N_NOOP("Not in sync file"),
+                                 I18N_NOOP("Plural"),
+                                 I18N_NOOP("Non-plural"),
                                  };
     const char* const* extTitles=Catalog::states();
     const char* const* alltitles[2]={basicTitles,extTitles};
@@ -212,6 +218,10 @@ void CatalogView::fillFilterOptionsMenu()
     QMenu* columnsMenu=m_filterOptionsMenu->addMenu(i18nc("@title:inmenu","Searchable column"));
 
     QAction* txt;
+    txt=m_filterOptionsMenu->addAction(i18nc("@title:inmenu","Resort and refilter on content change"), m_proxyModel, SLOT(setDynamicSortFilter(bool)));
+    txt->setCheckable(true);
+    txt->setChecked(m_proxyModel->dynamicSortFilter());
+
     for (int i=0;(1<<i)<CatalogTreeFilterModel::MaxOption;++i)
     {
         bool ext=(1<<i)>=CatalogTreeFilterModel::New;
@@ -227,7 +237,7 @@ void CatalogView::fillFilterOptionsMenu()
         m_filterOptionsMenu->addSeparator();
     for (int i=-1;i<CatalogTreeModel::DisplayedColumnCount;++i)
     {
-        kWarning()<<i;
+        qWarning()<<i;
         txt=columnsMenu->addAction((i==-1)?i18nc("@item:inmenu all columns","All"):
                                                    m_model->headerData(i,Qt::Horizontal,Qt::DisplayRole).toString());
         txt->setData(-i-2);
@@ -250,7 +260,7 @@ void CatalogView::setMergeCatalogPointer(MergeCatalog* pointer)
     m_proxyModel->setMergeCatalogPointer(pointer);
 }
 
-int CatalogView::siblingEntry(int step)
+int CatalogView::siblingEntryNumber(int step)
 {
     QModelIndex item=m_browser->currentIndex();
     int lastRow=m_proxyModel->rowCount()-1;
@@ -270,14 +280,14 @@ int CatalogView::siblingEntry(int step)
     return m_proxyModel->mapToSource(item).row();
 }
 
-int CatalogView::nextEntry()
+int CatalogView::nextEntryNumber()
 {
-    return siblingEntry(1);
+    return siblingEntryNumber(1);
 }
 
-int CatalogView::prevEntry()
+int CatalogView::prevEntryNumber()
 {
-    return siblingEntry(-1);
+    return siblingEntryNumber(-1);
 }
 
 static int edgeEntry(CatalogTreeFilterModel* m_proxyModel, int row)
@@ -288,12 +298,12 @@ static int edgeEntry(CatalogTreeFilterModel* m_proxyModel, int row)
     return m_proxyModel->mapToSource(m_proxyModel->index(row,0)).row();
 }
 
-int CatalogView::firstEntry()
+int CatalogView::firstEntryNumber()
 {
     return edgeEntry(m_proxyModel,0);
 }
 
-int CatalogView::lastEntry()
+int CatalogView::lastEntryNumber()
 {
     return edgeEntry(m_proxyModel,m_proxyModel->rowCount()-1);
 }
@@ -310,5 +320,3 @@ void CatalogView::setEntriesFilteredOut(bool filteredOut)
     m_proxyModel->setEntriesFilteredOut(filteredOut);
 }
 
-
-#include "cataloglistview.moc"
