@@ -197,10 +197,14 @@ SearchJob::SearchJob(const QStringList& f, const SearchParams& sp, const QVector
 void SearchJob::run()
 {
     QTime a;a.start();
+    bool removeAmpFromSource = searchParams.sourcePattern.patternSyntax()==QRegExp::FixedString
+                            && !searchParams.sourcePattern.pattern().contains(QLatin1Char('&'));
+    bool removeAmpFromTarget = searchParams.targetPattern.patternSyntax()==QRegExp::FixedString
+                            && !searchParams.targetPattern.pattern().contains(QLatin1Char('&'));
     foreach(const QString& filePath, files)
     {
         Catalog catalog(0); 
-        if (KDE_ISUNLIKELY(catalog.loadFromUrl(filePath, QString(), &m_size)!=0))
+        if (KDE_ISUNLIKELY(catalog.loadFromUrl(filePath, QString(), &m_size, true)!=0))
             continue;
 
         //QVector<FileSearchResult> catalogResults;
@@ -216,9 +220,9 @@ void SearchJob::run()
                 int sp=0;
                 int tp=0;
                 if (!searchParams.sourcePattern.isEmpty())
-                    sp=searchParams.sourcePattern.indexIn(catalog.source(pos));
+                    sp=searchParams.sourcePattern.indexIn(removeAmpFromSource?catalog.source(pos).remove(QLatin1Char('&')):catalog.source(pos));
                 if (!searchParams.targetPattern.isEmpty())
-                    tp=searchParams.targetPattern.indexIn(catalog.target(pos));
+                    tp=searchParams.targetPattern.indexIn(removeAmpFromTarget?catalog.target(pos).remove(QLatin1Char('&')):catalog.target(pos));
                 //int np=searchParams.notesPattern.indexIn(catalog.notes(pos));
 
                 if ((sp!=-1)!=searchParams.invertSource && (tp!=-1)!=searchParams.invertTarget)
@@ -259,7 +263,7 @@ void SearchJob::run()
         //if (catalogResults.size())
         //    results[path]=catalogResults;
     }
-    qDebug()<<"done in"<<a.elapsed();
+    qDebug()<<"searching took"<<a.elapsed();
     emit done(this);
 }
 
@@ -382,10 +386,10 @@ QVariant FileSearchModel::data(const QModelIndex& item, int role) const
             if (result.isEmpty())
                 return result;
 
-            static QString startBld="_ST_";
-            static QString endBld="_END_";
-            static QString startBldTag="<b >";
-            static QString endBldTag="</b >";
+            const QString startBld = QStringLiteral("_ST_");
+            const QString endBld = QStringLiteral("_END_");
+            const QString startBldTag = QStringLiteral("<b >");
+            const QString endBldTag = QStringLiteral("</b >");
 
             if (item.column()==FileSearchModel::Target && !m_replaceWhat.isEmpty())
             {
@@ -428,7 +432,7 @@ QVariant FileSearchModel::data(const QModelIndex& item, int role) const
 void FileSearchModel::setReplacePreview(const QRegExp& s, const QString& r)
 {
     m_replaceWhat=s;
-    m_replaceWith="_ST_" % r % "_END_";
+    m_replaceWith=QLatin1String("_ST_") % r % QLatin1String("_END_");
     
     emit dataChanged(index(0, Target), index(rowCount()-1, Target));
 }
@@ -627,10 +631,11 @@ void FileSearchTab::performSearch()
 
 void FileSearchTab::stopSearch()
 {
-    QVector<QRunnable*>::const_iterator it;
-    ///// KDE5PORT
-    ////for (it = m_runningJobs.constBegin(); it != m_runningJobs.constEnd(); ++it)
-    ////    ThreadWeaver::Weaver::instance()->dequeue(*it);
+#if QT_VERSION >= 0x050500
+    int i=m_runningJobs.size();
+    while (--i>=0)
+        QThreadPool::globalInstance()->cancel(m_runningJobs.at(i));
+#endif
     m_runningJobs.clear();
 }
 
