@@ -133,6 +133,8 @@ void LokalizeMainWindow::initLater()
 
 LokalizeMainWindow::~LokalizeMainWindow()
 {
+    TM::cancelAllJobs();
+
     KConfig config;
     KConfigGroup stateGroup(&config,"State");
     saveProjectState(stateGroup);
@@ -241,7 +243,7 @@ bool LokalizeMainWindow::queryClose()
     
     if (ok)
     {
-        TM::cancelAllJobs(); //this shit works l)
+        QThreadPool::globalInstance()->clear();
         Project::instance()->model()->threadPool()->clear();
     }
     return ok;
@@ -554,7 +556,7 @@ void LokalizeMainWindow::setupActions()
 
     setupGUI(Default,QStringLiteral("lokalizemainwindowui.rc"));
 
-    qWarning()<<"finished"<<aaa.elapsed();
+    //qDebug()<<"action setup finished"<<aaa.elapsed();
 }
 
 bool LokalizeMainWindow::closeProject()
@@ -819,10 +821,10 @@ ProjectScriptingPlugin::ProjectScriptingPlugin(QObject* lokalize, QObject* edito
     }
 
     //qWarning()<<Kross::Manager::self().hasInterpreterInfo("python");
-    addObject(lokalize,"Lokalize",ChildrenInterface::AutoConnectSignals);
-    addObject(Project::instance(),"Project",ChildrenInterface::AutoConnectSignals);
-    addObject(editor,"Editor",ChildrenInterface::AutoConnectSignals);
-    setXMLFile("scriptsui.rc",true);
+    addObject(lokalize,QLatin1String("Lokalize"),ChildrenInterface::AutoConnectSignals);
+    addObject(Project::instance(),QLatin1String("Project"),ChildrenInterface::AutoConnectSignals);
+    addObject(editor,QLatin1String("Editor"),ChildrenInterface::AutoConnectSignals);
+    setXMLFile(QLatin1String("scriptsui.rc"),true);
 }
 
 void ProjectScriptingPlugin::setDOMDocument (const QDomDocument &document, bool merge)
@@ -883,7 +885,7 @@ void LokalizeMainWindow::checkForProjectAlreadyOpened()
 void LokalizeMainWindow::registerDBusAdaptor()
 {
     new MainWindowAdaptor(this);
-    QDBusConnection::sessionBus().registerObject("/ThisIsWhatYouWant", this);
+    QDBusConnection::sessionBus().registerObject(QLatin1String("/ThisIsWhatYouWant"), this);
 
     //qWarning()<<QDBusConnection::sessionBus().interface()->registeredServiceNames().value();
 #ifndef Q_OS_MAC
@@ -985,7 +987,7 @@ QString LokalizeMainWindow::currentProject(){return Project::instance()->path();
 
 #include <unistd.h>
 int LokalizeMainWindow::pid(){return getpid();}
-QString LokalizeMainWindow::dbusName(){return QString("org.kde.lokalize-%1").arg(pid());}
+QString LokalizeMainWindow::dbusName(){return QStringLiteral("org.kde.lokalize-%1").arg(pid());}
 void LokalizeMainWindow::busyCursor(bool busy){busy?QApplication::setOverrideCursor(Qt::WaitCursor):QApplication::restoreOverrideCursor();}
 // void LokalizeMainWindow::processEvents(){QCoreApplication::processEvents();}
 
@@ -1024,7 +1026,7 @@ DelayedFileOpener::DelayedFileOpener(const QVector<QString>& urls, LokalizeMainW
  , m_urls(urls)
  , m_lmw(lmw)
 {
-    //do the work just after project load handlind is finished
+    //do the work just after project loading is finished
     //(i.e. all the files from previous project session are loaded)
     QTimer::singleShot(1,this,SLOT(doOpen()));
 }
