@@ -71,6 +71,9 @@ QThreadPool* TM::threadPool()
 static bool stop=false;
 void TM::cancelAllJobs(){stop=true;}
 
+static qlonglong newTMSourceEntryCount = 0;
+static qlonglong reusedTMSourceEntryCount = 0;
+
 /**
  * splits string into words, removing any markup
  *
@@ -122,11 +125,11 @@ static qlonglong getFileId(const QString& path,
     QString pathExpr=QStringLiteral("path='")%escapedPath%'\'';
     if (path.isEmpty())
         pathExpr=QStringLiteral("path ISNULL");
-    if (KDE_ISUNLIKELY(!query1.exec(U("SELECT id FROM files WHERE "
+    if (Q_UNLIKELY(!query1.exec(U("SELECT id FROM files WHERE "
                      "path='")%escapedPath%'\'')))
         qWarning() <<"select db error: " <<query1.lastError().text();
 
-    if (KDE_ISLIKELY(query1.next()))
+    if (Q_LIKELY(query1.next()))
     {
         //this is translation of en string that is already present in db
 
@@ -144,7 +147,7 @@ static qlonglong getFileId(const QString& path,
     query1.prepare(sql);
 
     query1.bindValue(0, path);
-    if (KDE_ISLIKELY(query1.exec()))
+    if (Q_LIKELY(query1.exec()))
         return qpsql ? (query1.next(), query1.value(0).toLongLong()) : query1.lastInsertId().toLongLong();
     else
         qWarning() <<"insert db error: " <<query1.lastError().text();
@@ -161,7 +164,7 @@ static void addToIndex(qlonglong sourceId, QString sourceString,
     QStringList words;
     doSplit(sourceString,words,rxClean1,accel);
 
-    if (KDE_ISUNLIKELY( words.isEmpty() ))
+    if (Q_UNLIKELY( words.isEmpty() ))
         return;
 
     QSqlQuery query1(db);
@@ -173,7 +176,7 @@ static void addToIndex(qlonglong sourceId, QString sourceString,
     while (--j>=0)
     {
         // insert word (if we do not have it)
-        if (KDE_ISUNLIKELY(!query1.exec(U("SELECT word, ids_short, ids_long FROM words WHERE "
+        if (Q_UNLIKELY(!query1.exec(U("SELECT word, ids_short, ids_long FROM words WHERE "
                     "word='")%words.at(j)%'\'')))
             qWarning() <<"select error 3: " <<query1.lastError().text();
 
@@ -210,7 +213,7 @@ static void addToIndex(qlonglong sourceId, QString sourceString,
             arr+=sourceIdStr;
             query1.bindValue(0, arr);
 
-            if (KDE_ISUNLIKELY(!query1.exec()))
+            if (Q_UNLIKELY(!query1.exec()))
                 qWarning() <<"update error 4: " <<query1.lastError().text();
 
         }
@@ -227,7 +230,7 @@ static void addToIndex(qlonglong sourceId, QString sourceString,
             query1.bindValue(0, words.at(j));
             query1.bindValue(1, idsShort);
             query1.bindValue(2, idsLong);
-            if (KDE_ISUNLIKELY(!query1.exec()))
+            if (Q_UNLIKELY(!query1.exec()))
                 qWarning() <<"insert error 2: " <<query1.lastError().text() ;
 
         }
@@ -244,7 +247,7 @@ static void removeFromIndex(qlonglong mainId, qlonglong sourceId, QString source
     QStringList words;
     doSplit(sourceString,words,rxClean1,accel);
 
-    if (KDE_ISUNLIKELY( words.isEmpty() ))
+    if (Q_UNLIKELY( words.isEmpty() ))
         return;
 
     QSqlQuery query1(db);
@@ -252,7 +255,7 @@ static void removeFromIndex(qlonglong mainId, qlonglong sourceId, QString source
 
 //BEGIN check
     //TM_NOTAPPROVED=4
-    if (KDE_ISUNLIKELY(!query1.exec(U("SELECT count(*) FROM main, target_strings WHERE "
+    if (Q_UNLIKELY(!query1.exec(U("SELECT count(*) FROM main, target_strings WHERE "
                     "main.source=")%QString::number(sourceId)%U(" AND "
                     "main.target=target_strings.id AND "
                     "target_strings.target NOTNULL AND "
@@ -274,7 +277,7 @@ static void removeFromIndex(qlonglong mainId, qlonglong sourceId, QString source
     while (--j>=0)
     {
         // remove from record for the word (if we do not have it)
-        if (KDE_ISUNLIKELY(!query1.exec(U("SELECT word, ids_short, ids_long FROM words WHERE "
+        if (Q_UNLIKELY(!query1.exec(U("SELECT word, ids_short, ids_long FROM words WHERE "
                     "word='")%words.at(j)%'\'')))
         {
             qWarning() <<"select error 3: " <<query1.lastError().text();
@@ -318,7 +321,7 @@ static void removeFromIndex(qlonglong mainId, qlonglong sourceId, QString source
 
         query1.bindValue(0, arr);
 
-        if (KDE_ISUNLIKELY(!query1.exec()))
+        if (Q_UNLIKELY(!query1.exec()))
             qWarning() <<"update error 504: " <<query1.lastError().text();
 
     }
@@ -328,7 +331,7 @@ static bool doRemoveEntry(qlonglong mainId, QRegExp& rxClean1, const QString& ac
 {
     QSqlQuery query1(db);
 
-    if (KDE_ISUNLIKELY(!query1.exec(U("SELECT source_strings.id, source_strings.source FROM source_strings, main WHERE "
+    if (Q_UNLIKELY(!query1.exec(U("SELECT source_strings.id, source_strings.source FROM source_strings, main WHERE "
                      "source_strings.id=main.source AND main.id=")+QString::number(mainId))))
         return false;
 
@@ -351,7 +354,7 @@ static bool doRemoveEntry(qlonglong mainId, QRegExp& rxClean1, const QString& ac
         qWarning()<<"ok delete?"<<query1.exec(QStringLiteral("DELETE FROM source_strings WHERE id=")+QString::number(sourceId));
     }
 
-    if (KDE_ISUNLIKELY(!query1.exec(U("SELECT target FROM main WHERE "
+    if (Q_UNLIKELY(!query1.exec(U("SELECT target FROM main WHERE "
                      "main.id=")+QString::number(mainId))
             || !query1.next()))
         return false;
@@ -372,7 +375,7 @@ static bool doRemoveEntry(qlonglong mainId, QRegExp& rxClean1, const QString& ac
 
 static QString escape(QString str)
 {
-    return str.replace('\'',"''");
+    return str.replace(QLatin1Char('\''),QStringLiteral("''"));
 }
 
 static bool doInsertEntry(CatalogString source,
@@ -391,7 +394,7 @@ static bool doInsertEntry(CatalogString source,
 
     mainId=-1;
 
-    if (KDE_ISUNLIKELY( source.isEmpty() ))
+    if (Q_UNLIKELY( source.isEmpty() ))
     {
         qWarning()<<"source empty";
         return false;
@@ -421,15 +424,15 @@ static bool doInsertEntry(CatalogString source,
 //BEGIN get sourceId
     query1.prepare(QString(U("SELECT id FROM source_strings WHERE "
                      "source=? AND (source_accel%1) AND source_markup%2")).arg
-                                    (sourceAccelPos!=-1?QStringLiteral("=?"):QStringLiteral("=-1 OR source_accel ISNULL")).arg
-                                    (sourceTags.isEmpty()?QStringLiteral(" ISNULL"):QStringLiteral("=?")));
+                                    (sourceAccelPos!=-1?QStringLiteral("=?"):QStringLiteral("=-1 OR source_accel ISNULL"),
+                                     sourceTags.isEmpty()?QStringLiteral(" ISNULL"):QStringLiteral("=?")));
     int paranum=0;
     query1.bindValue(paranum++,source.string);
     if (sourceAccelPos!=-1)
         query1.bindValue(paranum++,sourceAccelPos);
     if (!sourceTags.isEmpty())
         query1.bindValue(paranum++,sourceTags);
-    if (KDE_ISUNLIKELY(!query1.exec()))
+    if (Q_UNLIKELY(!query1.exec()))
     {
         qWarning() <<"select db source_strings error: " <<query1.lastError().text();
         return false;
@@ -438,7 +441,8 @@ static bool doInsertEntry(CatalogString source,
     if (!query1.next())
     {
 //BEGIN insert source anew
-        qDebug() <<"insert source anew";;
+        //qDebug() <<"insert source anew";;
+        ++newTMSourceEntryCount;
 
         QString sql=QStringLiteral("INSERT INTO source_strings (source, source_markup, source_accel) VALUES (?, ?, ?)");
         if (qpsql)
@@ -450,7 +454,7 @@ static bool doInsertEntry(CatalogString source,
         query1.bindValue(0, source.string);
         query1.bindValue(1, sourceTags);
         query1.bindValue(2, sourceAccelPos!=-1?QVariant(sourceAccelPos):QVariant());
-        if (KDE_ISUNLIKELY(!query1.exec()))
+        if (Q_UNLIKELY(!query1.exec()))
         {
             qWarning() <<"select db source_strings error: " <<query1.lastError().text();
             return false;
@@ -466,13 +470,14 @@ static bool doInsertEntry(CatalogString source,
     else
     {
         sourceId=query1.value(0).toLongLong();
+        ++reusedTMSourceEntryCount;
         //qDebug()<<"SOURCE ALREADY PRESENT"<<source.string<<sourceId;
     }
     query1.clear();
 //END get sourceId
 
 
-    if (KDE_ISUNLIKELY(!query1.exec(QString(U("SELECT id, target, bits FROM main WHERE "
+    if (Q_UNLIKELY(!query1.exec(QString(U("SELECT id, target, bits FROM main WHERE "
                      "source=%1 AND file=%2 AND ctxt%3")).arg(sourceId).arg(fileId).arg
                                         (escapedCtxt.isEmpty()?QStringLiteral(" ISNULL"):QString("='"%escapedCtxt%'\'')))))
     {
@@ -510,7 +515,7 @@ static bool doInsertEntry(CatalogString source,
                              "WHERE id=")+QString::number(mainId));
 
             query1.bindValue(0, bits^TM_NOTAPPROVED);
-            if (KDE_ISUNLIKELY(!query1.exec()))
+            if (Q_UNLIKELY(!query1.exec()))
             {
                 qWarning()<<"fail #9"<<query1.lastError().text();
                 return false;
@@ -519,14 +524,14 @@ static bool doInsertEntry(CatalogString source,
         query1.clear();
 
         //check if target in TM matches
-        if (KDE_ISUNLIKELY(!query1.exec(U("SELECT target, target_markup, target_accel FROM target_strings WHERE "
+        if (Q_UNLIKELY(!query1.exec(U("SELECT target, target_markup, target_accel FROM target_strings WHERE "
                          "id=")+QString::number(targetId))))
         {
             qWarning()<<"select db target_strings error: " <<query1.lastError().text();
             return false;
         }
 
-        if (KDE_ISUNLIKELY(!query1.next()))
+        if (Q_UNLIKELY(!query1.next()))
         {
             qWarning()<<"linking to non-existing target should never happen";
             return false;
@@ -556,7 +561,7 @@ static bool doInsertEntry(CatalogString source,
             return false;
         }
         // no, translation has changed: just update old target if it isn't used elsewhere
-        if (KDE_ISUNLIKELY(!query1.exec(U("SELECT count(*) FROM main WHERE "
+        if (Q_UNLIKELY(!query1.exec(U("SELECT count(*) FROM main WHERE "
                          "target=")+QString::number(targetId))))
             qWarning() <<"select db target_strings error: " <<query1.lastError().text();
 
@@ -588,15 +593,15 @@ static bool doInsertEntry(CatalogString source,
 //BEGIN get targetId
     query1.prepare(QString(U("SELECT id FROM target_strings WHERE "
                      "target=? AND (target_accel%1) AND target_markup%2")).arg
-                                (targetAccelPos!=-1?QStringLiteral("=?"):QStringLiteral("=-1 OR target_accel ISNULL")).arg
-                                (targetTags.isEmpty()?QStringLiteral(" ISNULL"):QStringLiteral("=?")));
+                                (targetAccelPos!=-1?QStringLiteral("=?"):QStringLiteral("=-1 OR target_accel ISNULL"),
+                                 targetTags.isEmpty()?QStringLiteral(" ISNULL"):QStringLiteral("=?")));
     paranum=0;
     query1.bindValue(paranum++,target.string);
     if (targetAccelPos!=-1)
         query1.bindValue(paranum++,targetAccelPos);
     if (!targetTags.isEmpty())
         query1.bindValue(paranum++,targetTags);
-    if (KDE_ISUNLIKELY(!query1.exec()))
+    if (Q_UNLIKELY(!query1.exec()))
     {
         qWarning() <<"select db target_strings error: " <<query1.lastError().text();
         return false;
@@ -614,7 +619,7 @@ static bool doInsertEntry(CatalogString source,
         query1.bindValue(0, target.string);
         query1.bindValue(1, target.tagsAsByteArray());
         query1.bindValue(2, targetAccelPos!=-1?QVariant(targetAccelPos):QVariant());
-        if (KDE_ISUNLIKELY(!query1.exec()))
+        if (Q_UNLIKELY(!query1.exec()))
         {
             qWarning()<<"error inserting";
             return false;
@@ -873,15 +878,17 @@ static void setConfig(QSqlDatabase& db, const TMConfig& c)
     query.addBindValue(0);
     query.addBindValue(c.markup);
     //qDebug()<<"setting tm db config:"<<query.exec();
-    qDebug()<<"setting tm db config 1:"<<query.exec();
+    bool ok=query.exec();
+    if (!ok)
+        qWarning()<<"setting tm db config failed";
 
     query.addBindValue(1);
     query.addBindValue(c.accel);
-    qDebug()<<"setting tm db config 2:"<<query.exec();
+    query.exec();
 
     query.addBindValue(2);
     query.addBindValue(c.sourceLangCode);
-    qDebug()<<"setting tm db config 3:"<<query.exec();
+    query.exec();
 
     query.addBindValue(3);
     query.addBindValue(c.targetLangCode);
@@ -900,7 +907,6 @@ static TMConfig getConfig(QSqlDatabase& db, bool useCache=true) //int& emptyTarg
 
     QSqlQuery query(db);
     bool ok=query.exec(QStringLiteral("SELECT key, value FROM tm_config ORDER BY key ASC"));
-    qDebug()<<"accessing tm db config"<<ok<<"use cache:"<<useCache;
     Project& p=*(Project::instance());
     bool f=query.next();
     TMConfig c;
@@ -910,9 +916,12 @@ static TMConfig getConfig(QSqlDatabase& db, bool useCache=true) //int& emptyTarg
     c.targetLangCode=query.next()?query.value(1).toString():p.targetLangCode();
     query.clear();
 
-    if (KDE_ISUNLIKELY(  !f )) //tmConfigCache[db.databaseName()]=c;
+    if (Q_UNLIKELY(  !f )) //tmConfigCache[db.databaseName()]=c;
         setConfig(db,c);
 
+    if (!ok)
+        qWarning()<<"accessing tm db config"<<ok<<"use cache:"<<useCache<<"lang:"<<c.sourceLangCode<<c.targetLangCode;
+
     tmConfigCache.insert(db.databaseName(), c);
     return c;
 }
@@ -925,32 +934,38 @@ static void getStats(const QSqlDatabase& db,
                     )
 
 {
-    qDebug()<<"getStats"<<db.databaseName();
-
     QSqlQuery query(db);
     if (!query.exec(QStringLiteral("SELECT count(id) FROM main"))
         || !query.next())
+    {
+        qWarning()<<"getStats fail"<<db.databaseName();
         return;
+    }
     pairsCount=query.value(0).toInt();
     query.clear();
 
     if(!query.exec(QStringLiteral("SELECT count(*) FROM source_strings"))
         || !query.next())
+    {
+        qWarning()<<"getStats fail"<<db.databaseName();
         return;
+    }
     uniqueSourcesCount=query.value(0).toInt();
     query.clear();
 
     if(!query.exec(QStringLiteral("SELECT count(*) FROM target_strings"))
         || !query.next())
+    {
+        qWarning()<<"getStats fail"<<db.databaseName();
         return;
+    }
     uniqueTranslationsCount=query.value(0).toInt();
 
-    qDebug()<<"getStats ok";
     query.clear();
 }
 
-OpenDBJob::OpenDBJob(const QString& name, DbType type, bool reconnect, const ConnectionParams& connParams, QObject*)
-    : QRunnable()
+OpenDBJob::OpenDBJob(const QString& name, DbType type, bool reconnect, const ConnectionParams& connParams)
+    : QObject(), QRunnable()
     , m_dbName(name)
     , m_type(type)
     , m_setParams(false)
@@ -959,12 +974,12 @@ OpenDBJob::OpenDBJob(const QString& name, DbType type, bool reconnect, const Con
     , m_connParams(connParams)
 {
     setAutoDelete(false);
-    qDebug()<<m_dbName;
+    //qDebug()<<"OpenDBJob ctor"<<m_dbName;
 }
 
 OpenDBJob::~OpenDBJob()
 {
-    qDebug()<<m_dbName;
+    //qDebug()<<"OpenDBJob dtor"<<m_dbName;
 }
 
 void OpenDBJob::run()
@@ -982,7 +997,7 @@ void OpenDBJob::run()
             if (!fileInfo.exists(dbFolder)) fileInfo.absoluteDir().mkpath(fileInfo.fileName());
             db.setDatabaseName(dbFolder % QLatin1Char('/') % m_dbName % TM_DATABASE_EXTENSION);
             m_connectionSuccessful=db.open();
-            if (KDE_ISUNLIKELY( !m_connectionSuccessful ))
+            if (Q_UNLIKELY( !m_connectionSuccessful ))
             {
                 qDebug()<<"failed to open db"<<db.databaseName()<<db.lastError().text();
                 QSqlDatabase::removeDatabase(m_dbName);
@@ -1039,7 +1054,7 @@ void OpenDBJob::run()
             db.setUserName(m_connParams.user);
             db.setPassword(m_connParams.passwd);
             m_connectionSuccessful=db.open();
-            if (KDE_ISUNLIKELY( !m_connectionSuccessful ))
+            if (Q_UNLIKELY( !m_connectionSuccessful ))
             {
                 QSqlDatabase::removeDatabase(m_dbName);
                 emit done(this);
@@ -1056,7 +1071,7 @@ void OpenDBJob::run()
         setConfig(db,m_tmConfig);
     else
         m_tmConfig=getConfig(db);
-    qWarning() <<"db"<<m_dbName<<" opened "<<a.elapsed()<<m_tmConfig.targetLangCode;
+    qDebug() <<"db"<<m_dbName<<"opened"<<a.elapsed()<<m_tmConfig.targetLangCode;
 
     getStats(db,m_stat.pairsCount,m_stat.uniqueSourcesCount,m_stat.uniqueTranslationsCount);
     
@@ -1069,8 +1084,8 @@ void OpenDBJob::run()
 }
 
 
-CloseDBJob::CloseDBJob(const QString& name, QObject*)
-    : QRunnable()
+CloseDBJob::CloseDBJob(const QString& name)
+    : QObject(), QRunnable()
     , m_dbName(name)
 {
     setAutoDelete(false);
@@ -1078,7 +1093,7 @@ CloseDBJob::CloseDBJob(const QString& name, QObject*)
 
 CloseDBJob::~CloseDBJob()
 {
-    qWarning()<<m_dbName;
+    qDebug()<<"closedb dtor"<<m_dbName;
 }
 
 void CloseDBJob::run ()
@@ -1119,9 +1134,8 @@ SelectJob::SelectJob(const CatalogString& source,
                      const QString& ctxt,
                      const QString& file,
                      const DocPosition& pos,
-                     const QString& dbName,
-                     QObject*)
-    : QRunnable()
+                     const QString& dbName)
+    : QObject(), QRunnable()
     , m_source(source)
     , m_ctxt(ctxt)
     , m_file(file)
@@ -1155,7 +1169,7 @@ bool SelectJob::doSelect(QSqlDatabase& db,
                          //QList<TMEntry>& entries,
                          bool isShort)
 {
-    bool qpsql=(db.driverName()==QLatin1String("QPSQL"));
+    bool qpsql = (db.driverName()==QLatin1String("QPSQL"));
     QMap<qlonglong,uint> occurencies;
     QVector<qlonglong> idsForWord;
 
@@ -1174,7 +1188,7 @@ bool SelectJob::doSelect(QSqlDatabase& db,
         {
             idsForWord.clear();
             queryWords.exec(queryString.arg(words.at(o)));
-            if (KDE_ISUNLIKELY(!queryWords.exec(queryString.arg(words.at(o)))))
+            if (Q_UNLIKELY(!queryWords.exec(queryString.arg(words.at(o)))))
                 qWarning() <<"select error: " <<queryWords.lastError().text() << endl;
 
             if (queryWords.next())
@@ -1207,7 +1221,7 @@ bool SelectJob::doSelect(QSqlDatabase& db,
     QString tmp=c.markup;
     if (!c.markup.isEmpty())
         tmp+='|';
-    QRegExp rxSplit('('%tmp%QStringLiteral("\\W+|\\d+)+"));
+    QRegExp rxSplit(QLatin1Char('(') % tmp % QStringLiteral("\\W+|\\d+)+"));
 
     QString sourceClean(m_source.string);
     sourceClean.remove(c.accel);
@@ -1228,7 +1242,7 @@ bool SelectJob::doSelect(QSqlDatabase& db,
     if (concordanceLevelToIds.size()) --clit;
     if (concordanceLevelToIds.size()) while (--limit>=0)
     {
-        if (KDE_ISUNLIKELY( m_dequeued ))
+        if (Q_UNLIKELY( m_dequeued ))
             break;
 
         //for every concordance level
@@ -1258,7 +1272,7 @@ bool SelectJob::doSelect(QSqlDatabase& db,
             if (e.source.string.contains(TAGRANGE_IMAGE_SYMBOL))
             {
                 if (!e.source.tags.size())
-                    qWarning()<<queryFetch.value(3).toByteArray().size()<<queryFetch.value(3).toByteArray();
+                    qWarning()<<"problem:"<<queryFetch.value(3).toByteArray().size()<<queryFetch.value(3).toByteArray();
             }
             //e.target=queryFetch.value(2).toString();
             //QStringList e_ctxt=queryFetch.value(3).toString().split('\b',QString::SkipEmptyParts);
@@ -1463,13 +1477,13 @@ void SelectJob::run ()
     //thread()->setPriority(QThread::IdlePriority);
     QTime a;a.start();
 
-    if (KDE_ISUNLIKELY( !QSqlDatabase::contains(m_dbName) ))
+    if (Q_UNLIKELY( !QSqlDatabase::contains(m_dbName) ))
     {
         emit done(this);
         return;
     }
     QSqlDatabase db=QSqlDatabase::database(m_dbName);
-    if (KDE_ISUNLIKELY(!db.isValid() || !db.isOpen() ))
+    if (Q_UNLIKELY(!db.isValid() || !db.isOpen() ))
     {
         emit done(this);
         return;
@@ -1482,7 +1496,7 @@ void SelectJob::run ()
     QString cleanSource=m_source.string;
     QStringList words;
     doSplit(cleanSource,words,rxClean1,c.accel);
-    if (KDE_ISUNLIKELY( words.isEmpty() ))
+    if (Q_UNLIKELY( words.isEmpty() ))
     {
         emit done(this);
         return;
@@ -1501,7 +1515,7 @@ void SelectJob::run ()
     while(--i>=limit)
         m_entries.removeLast();
 
-    if (KDE_ISUNLIKELY( m_dequeued ))
+    if (Q_UNLIKELY( m_dequeued ))
     {
         emit done(this);
         return;
@@ -1525,7 +1539,7 @@ void SelectJob::run ()
 
 
 
-ScanJob::ScanJob(const QString& filePath, const QString& dbName, QObject* parent)
+ScanJob::ScanJob(const QString& filePath, const QString& dbName)
     : QRunnable()
     , m_filePath(filePath)
     , m_time(0)
@@ -1539,14 +1553,15 @@ ScanJob::ScanJob(const QString& filePath, const QString& dbName, QObject* parent
 
 ScanJob::~ScanJob()
 {
-    qWarning() <<m_filePath;
 }
 
 void ScanJob::run()
 {
     if (stop || !QSqlDatabase::contains(m_dbName))
-      return;
-    qWarning() <<"scan job started for"<<m_filePath<<m_dbName<<stop<<m_dbName;
+    {
+        return;
+    }
+    qWarning()<<"scan job started for"<<m_filePath<<m_dbName<<stop<<m_dbName;
     //QThread::currentThread()->setPriority(QThread::IdlePriority);
     QTime a;a.start();
 
@@ -1557,8 +1572,8 @@ void ScanJob::run()
     TMConfig c=getConfig(db,true);
     QRegExp rxClean1(c.markup);rxClean1.setMinimal(true);
 
-    Catalog catalog(QThread::currentThread());
-    if (KDE_ISLIKELY(catalog.loadFromUrl(m_filePath, QString(), &m_size, /*no auto save*/true)==0))
+    Catalog catalog(0);
+    if (Q_LIKELY(catalog.loadFromUrl(m_filePath, QString(), &m_size, /*no auto save*/true)==0))
     {
         if (c.targetLangCode!=catalog.targetLangCode())
         {
@@ -1610,40 +1625,42 @@ void ScanJob::run()
                                  catalog.isApproved(pos),
                                  fileId,db,rxClean1,c.accel,priorId,priorId);
             }
-            if (KDE_ISLIKELY( ok ))
+            if (Q_LIKELY( ok ))
                 ++m_added;
         }
         QSqlQuery queryEnd(QStringLiteral("END"),db);
-        qWarning() <<"ScanJob: done "<<a.elapsed();
+        qDebug() <<"ScanJob: done "<<a.elapsed()<<"new source entries:"<<newTMSourceEntryCount<<"reused:"<<reusedTMSourceEntryCount;
     }
     //qWarning() <<"Done scanning "<<m_url.prettyUrl();
     m_time=a.elapsed();
 }
 
 
-RemoveJob::RemoveJob(const TMEntry& entry, QObject*)
-    : QRunnable()
+RemoveJob::RemoveJob(const TMEntry& entry)
+    : QObject(), QRunnable()
     , m_entry(entry)
 {
-    qWarning()<<"removing"<<m_entry.file<<m_entry.source.string;
+    //RemoveJob instances are deleted automatically because their signal does not contain pointer to the job
+    qDebug()<<"removing"<<m_entry.dbName<<m_entry.file<<m_entry.source.string;
 }
 
 RemoveJob::~RemoveJob()
 {
-    qWarning()<<m_entry.file<<m_entry.source.string;
+    qDebug()<<"removejob dtor"<<m_entry.dbName<<m_entry.file<<m_entry.source.string;
 }
 
 
 void RemoveJob::run ()
 {
-    qDebug()<<m_entry.dbName;
+//    qDebug()<<m_entry.dbName;
     QSqlDatabase db=QSqlDatabase::database(m_entry.dbName);
 
     //cleaning regexps for word index update
     TMConfig c=getConfig(db);
     QRegExp rxClean1(c.markup);rxClean1.setMinimal(true);
 
-    qWarning()<<doRemoveEntry(m_entry.id,rxClean1,c.accel,db);
+    if(!doRemoveEntry(m_entry.id,rxClean1,c.accel,db))
+        qWarning()<<"error removing entry"<<m_entry.dbName<<m_entry.file<<m_entry.source.string;
 
     emit done();
 }
@@ -1656,8 +1673,7 @@ UpdateJob::UpdateJob(const QString& filePath,
                      //const DocPosition&,//for back tracking
                      int form,
                      bool approved,
-                     const QString& dbName,
-                     QObject*)
+                     const QString& dbName)
     : QRunnable()
     , m_filePath(filePath)
     , m_ctxt(ctxt)
@@ -1672,7 +1688,7 @@ UpdateJob::UpdateJob(const QString& filePath,
 
 void UpdateJob::run ()
 {
-    qDebug()<<"run"<<m_english.string<<m_newTarget.string;
+    qDebug()<<"UpdateJob run"<<m_english.string<<m_newTarget.string;
     QSqlDatabase db=QSqlDatabase::database(m_dbName);
 
     //cleaning regexps for word index update
@@ -1776,7 +1792,7 @@ bool TmxParser::startDocument()
     //initSqliteDb(db);
     m_fileIds.clear();
 
-    QSqlQuery queryBegin("BEGIN",db);
+    QSqlQuery queryBegin(QLatin1String("BEGIN"),db);
 
     m_state=null;
     m_lang=Null;
@@ -1786,7 +1802,7 @@ bool TmxParser::startDocument()
 
 TmxParser::~TmxParser()
 {
-    QSqlQuery queryEnd("END",db);
+    QSqlQuery queryEnd(QLatin1String("END"),db);
 }
 
 
@@ -1797,7 +1813,7 @@ bool TmxParser::startElement( const QString&, const QString&,
     if (qName==QLatin1String("tu"))
     {
         bool ok;
-        m_hits=attr.value("usagecount").toInt(&ok);
+        m_hits=attr.value(QLatin1String("usagecount")).toInt(&ok);
         if (!ok)
             m_hits=-1;
 
@@ -1847,7 +1863,7 @@ bool TmxParser::startElement( const QString&, const QString&,
         {
             m_segment[m_lang].string+=QChar(TAGRANGE_IMAGE_SYMBOL);
             int pos=m_segment[m_lang].string.size();
-            m_inlineTags.append(InlineTag(pos, pos, t, attr.value("id")));
+            m_inlineTags.append(InlineTag(pos, pos, t, attr.value(QStringLiteral("id"))));
         }
     }
     return true;
@@ -1855,11 +1871,10 @@ bool TmxParser::startElement( const QString&, const QString&,
 
 bool TmxParser::endElement(const QString&,const QString&,const QString& qName)
 {
-    const char* tmxFilename="tmx-import";
     if (qName==QLatin1String("tu"))
     {
         if (m_filePath.isEmpty())
-            m_filePath=tmxFilename;
+            m_filePath=QLatin1String("tmx-import");
         if (!m_fileIds.contains(m_filePath))
             m_fileIds.insert(m_filePath,getFileId(m_filePath,db));
         qlonglong fileId=m_fileIds.value(m_filePath);
@@ -1873,7 +1888,7 @@ bool TmxParser::endElement(const QString&,const QString&,const QString& qName)
                               m_context,
                               m_approvedString!=QLatin1String("no"),
                               fileId,db,rxClean1,accel,priorId,priorId);
-        if (KDE_ISLIKELY( ok ))
+        if (Q_LIKELY( ok ))
             ++m_added;
     }
     else if (m_state==seg && m_lang!=Null)
@@ -1918,7 +1933,7 @@ bool TmxParser::characters ( const QString& ch )
 
 
 
-ImportTmxJob::ImportTmxJob(const QString& filename, const QString& dbName, QObject*)
+ImportTmxJob::ImportTmxJob(const QString& filename, const QString& dbName)
     : QRunnable()
     , m_filename(filename)
     , m_time(0)
@@ -1928,7 +1943,7 @@ ImportTmxJob::ImportTmxJob(const QString& filename, const QString& dbName, QObje
 
 ImportTmxJob::~ImportTmxJob()
 {
-    qWarning() <<"ImportTmxJob dtor ";
+    qWarning() <<"ImportTmxJob dtor";
 }
 
 void ImportTmxJob::run()
@@ -1945,7 +1960,7 @@ void ImportTmxJob::run()
 
     QXmlInputSource xmlInputSource(&file);
     if (!reader.parse(xmlInputSource))
-         qWarning() << "failed to load "<< m_filename;
+         qWarning() << "failed to load"<< m_filename;
 
     //qWarning() <<"Done scanning "<<m_url.prettyUrl();
     m_time=a.elapsed();
@@ -1956,7 +1971,7 @@ void ImportTmxJob::run()
 
 #include <QXmlStreamWriter>
 
-ExportTmxJob::ExportTmxJob(const QString& filename, const QString& dbName, QObject*)
+ExportTmxJob::ExportTmxJob(const QString& filename, const QString& dbName)
     : QRunnable()
     , m_filename(filename)
     , m_time(0)
@@ -1966,7 +1981,7 @@ ExportTmxJob::ExportTmxJob(const QString& filename, const QString& dbName, QObje
 
 ExportTmxJob::~ExportTmxJob()
 {
-    qWarning() <<"ExportTmxJob dtor ";
+    qDebug()<<"ExportTmxJob dtor";
 }
 
 void ExportTmxJob::run()
@@ -1993,7 +2008,7 @@ void ExportTmxJob::run()
         xmlOut.writeAttribute(QStringLiteral("o-encoding"),QStringLiteral("UTF-8"));
     xmlOut.writeEndElement();
 
-    xmlOut.writeStartElement("body");
+    xmlOut.writeStartElement(QStringLiteral("body"));
 
 
 
@@ -2002,7 +2017,7 @@ void ExportTmxJob::run()
     QSqlDatabase db=QSqlDatabase::database(m_dbName);
     QSqlQuery query1(db);
 
-    if (KDE_ISUNLIKELY(!query1.exec(U(
+    if (Q_UNLIKELY(!query1.exec(U(
                                     "SELECT main.id, main.ctxt, main.date, main.bits, "
                                     "source_strings.source, source_strings.source_accel, "
                                     "target_strings.target, target_strings.target_accel, "
@@ -2015,6 +2030,9 @@ void ExportTmxJob::run()
 
     TMConfig c=getConfig(db);
 
+    const QString DATE_FORMAT = QStringLiteral("yyyyMMdd");
+    const QString PROP = QStringLiteral("prop");
+    const QString TYPE = QStringLiteral("type");
     while (query1.next())
     {
         QString source=makeAcceledString(query1.value(4).toString(),c.accel,query1.value(5));
@@ -2024,7 +2042,7 @@ void ExportTmxJob::run()
             xmlOut.writeAttribute(QStringLiteral("tuid"),QString::number(query1.value(0).toLongLong()));
 
             xmlOut.writeStartElement(QStringLiteral("tuv"));
-                xmlOut.writeAttribute(QStringLiteral("xml:lang"),"en");
+                xmlOut.writeAttribute(QStringLiteral("xml:lang"),QStringLiteral("en"));
                 xmlOut.writeStartElement(QStringLiteral("seg"));
                     xmlOut.writeCharacters(source);
                 xmlOut.writeEndElement();
@@ -2032,8 +2050,8 @@ void ExportTmxJob::run()
 
             xmlOut.writeStartElement(QStringLiteral("tuv"));
                 xmlOut.writeAttribute(QStringLiteral("xml:lang"),dbLangCode);
-                xmlOut.writeAttribute(QStringLiteral("creationdate"),QDate::fromString(  query1.value(2).toString(), Qt::ISODate  ).toString("yyyyMMdd"));
-                xmlOut.writeAttribute(QStringLiteral("changedate"),QDate::fromString(  query1.value(9).toString(), Qt::ISODate  ).toString("yyyyMMdd"));
+                xmlOut.writeAttribute(QStringLiteral("creationdate"),QDate::fromString(  query1.value(2).toString(), Qt::ISODate  ).toString(DATE_FORMAT));
+                xmlOut.writeAttribute(QStringLiteral("changedate"),QDate::fromString(  query1.value(9).toString(), Qt::ISODate  ).toString(DATE_FORMAT));
                 QString ctxt=query1.value(1).toString();
                 if (!ctxt.isEmpty())
                 {
@@ -2043,15 +2061,15 @@ void ExportTmxJob::run()
                         QString plural=ctxt;
                         plural.remove(0,pos+1);
                         ctxt.remove(pos, plural.size());
-                        xmlOut.writeStartElement("prop");
-                            xmlOut.writeAttribute("type","x-pluralform");
+                        xmlOut.writeStartElement(PROP);
+                            xmlOut.writeAttribute(TYPE,"x-pluralform");
                             xmlOut.writeCharacters(plural);
                         xmlOut.writeEndElement();
                     }
                     if (!ctxt.isEmpty())
                     {
-                        xmlOut.writeStartElement("prop");
-                            xmlOut.writeAttribute("type","x-context");
+                        xmlOut.writeStartElement(PROP);
+                            xmlOut.writeAttribute(TYPE,"x-context");
                             xmlOut.writeCharacters(ctxt);
                         xmlOut.writeEndElement();
                     }
@@ -2059,8 +2077,8 @@ void ExportTmxJob::run()
                 QString filePath=query1.value(8).toString();
                 if (!filePath.isEmpty())
                 {
-                    xmlOut.writeStartElement("prop");
-                        xmlOut.writeAttribute("type","x-file");
+                    xmlOut.writeStartElement(PROP);
+                        xmlOut.writeAttribute(TYPE,"x-file");
                         xmlOut.writeCharacters(filePath);
                     xmlOut.writeEndElement();
                 }
@@ -2068,8 +2086,8 @@ void ExportTmxJob::run()
                 if (bits&TM_NOTAPPROVED)
                 if (!filePath.isEmpty())
                 {
-                    xmlOut.writeStartElement("prop");
-                        xmlOut.writeAttribute("type","x-approved");
+                    xmlOut.writeStartElement(PROP);
+                        xmlOut.writeAttribute(TYPE,"x-approved");
                         xmlOut.writeCharacters("no");
                     xmlOut.writeEndElement();
                 }
@@ -2088,7 +2106,7 @@ void ExportTmxJob::run()
     xmlOut.writeEndDocument();
     out.close();
 
-    qWarning() <<"Done exporting "<<a.elapsed();
+    qWarning()<<"ExportTmxJob done exporting:"<<a.elapsed();
     m_time=a.elapsed();
 }
 
@@ -2096,32 +2114,32 @@ void ExportTmxJob::run()
 //END TMX
 
 
-ExecQueryJob::ExecQueryJob(const QString& queryString, const QString& dbName, QObject*)
-    : QRunnable()
+ExecQueryJob::ExecQueryJob(const QString& queryString, const QString& dbName)
+    : QObject(), QRunnable()
     , query(0)
     , m_dbName(dbName)
     , m_query(queryString)
 {
     setAutoDelete(false);
-    qDebug()<<dbName<<queryString;
+    //qDebug()<<"ExecQueryJob"<<dbName<<queryString;
 }
 
 ExecQueryJob::~ExecQueryJob()
 {
     delete query;
-    qDebug()<<"destroy";
+    qDebug()<<"ExecQueryJob dtor";
 }
 
 void ExecQueryJob::run()
 {
     QSqlDatabase db=QSqlDatabase::database(m_dbName);
-    qDebug()<<"running"<<m_dbName<<"db.isOpen() ="<<db.isOpen();
+    qDebug()<<"ExecQueryJob"<<m_dbName<<"db.isOpen() ="<<db.isOpen();
     //temporarily:
     if (!db.isOpen())
-        qWarning()<<"db.open()="<<db.open();
+        qWarning()<<"ExecQueryJob db.open()="<<db.open();
     query=new QSqlQuery(m_query,db);
     query->exec();
-    qDebug()<<"done"<<query->lastError().text();
+    qDebug()<<"ExecQueryJob done"<<query->lastError().text();
     emit done(this);
 }
 
